@@ -396,12 +396,18 @@ class FuzzySystem(object):
 					den += value
 
 			try:
-				final_result[output] = num / den
+				if den == 0.0:
+					final_result[output] = 0.0
+					print("WARNING: the sum of rules' firing for variable '%s' is equal to 0. The result of the Sugeno inference was set to 0." % output)
+				else:
+					final_result[output] = num / den
+
 			except ArithmeticError:
 				if ignore_errors==True:
 					print("WARNING: cannot perform Sugeno inference for variable '%s'. The variable appears only as antecedent in the rules or an arithmetic error occurred." % output)
 				else:
 					raise Exception("ERROR: cannot perform Sugeno inference for variable '%s'. The variable appears only as antecedent in the rules or an arithmetic error occurred." % output)
+		
 		return final_result
 
 
@@ -489,7 +495,7 @@ class FuzzySystem(object):
 			terms= list(set(temp))
 
 		array_rules = array(self._rules, dtype='object')
-		result = self.mediate( terms, array_rules.T[0], array_rules.T[1], ignore_errors=ignore_errors )
+		result = self.mediate(terms, array_rules.T[0], array_rules.T[1], ignore_errors=ignore_errors)
 		return result
 
 
